@@ -5,7 +5,7 @@
 import csv
 import os
 import re
-from typing import Text, List, Set, Dict, Union
+from typing import Text, List, Set, Dict, Union, Tuple
 from faker import Faker
 from melon.loader import APPLICATION_FUNCTIONS
 
@@ -51,19 +51,16 @@ class ParameterizeUtil:
     """
 
     @staticmethod
-    def read_csv_dict(path: Text, headers: List[Text] = None) -> List[Dict]:
+    def read_csv_dict(path: Text, headers=None) -> List[Dict]:
         """
         读取csv内容
         :param path: csv文件路径
         :param headers: 表头(为空则默认取首行为表头)
         """
         with open(file=path, encoding='utf8', mode='rU') as csv_file:
-            contents = [ParameterizeUtil.__parse_func_all(line) for line in csv_file if not line.startswith('#')]
-            if CollUtil.is_empty(headers):
-                reader = csv.DictReader(contents)
-            else:
-                reader = csv.DictReader(contents, fieldnames=headers)
-            lines = list(reader)
+            contents = [ParameterizeUtil.__parse_expression_all(line) for line in csv_file
+                        if not line.startswith('#')]
+            lines = list(csv.DictReader(contents, fieldnames=headers))
         return lines
 
     @staticmethod
@@ -74,7 +71,7 @@ class ParameterizeUtil:
         :param ignore_first_line: 是否忽略首行
         """
         with open(path, encoding='utf8', mode='rU') as csv_file:
-            contents = [ParameterizeUtil.__parse_func_all(line) for line in csv_file if not line.startswith('#')]
+            contents = [ParameterizeUtil.__parse_expression_all(line) for line in csv_file if not line.startswith('#')]
             reader = csv.reader(contents)
             lines = list(reader)
         if ignore_first_line:
@@ -82,54 +79,57 @@ class ParameterizeUtil:
         return lines
 
     @staticmethod
-    def __parse_expression(expression: Text):
+    def __parse_expression_all(raw_str: Text):
         """
-        解析表达式
-        ${mock__xxx()} or ${mock__xxx}  调用 faker 中 mock 函数
-        ${melon__xxx()} or ${melon__xxx}  调用 application.py 中自定义函数
-        """
-        regex = r'^\${(mock|app)__(\w+?)(\(\))?}$'
-        res = re.search(regex, expression)
-        if not res:
-            return expression
+        解析所有表达式
+        ${mock__function_name()} 调用 faker 中 mock 函数
+        ${app__function_name()} 调用 application.py 中自定义函数
 
-        # mock 还是 application
-        prefix = res.group(1)
-        function_name = res.group(2)
-        if prefix == 'mock':
-            return eval(f'fa.{function_name}()')
-        elif prefix == 'app':
-            app_function = APPLICATION_FUNCTIONS.get(function_name)
-            return app_function() if app_function else expression
-        else:
-            return expression
+        :param raw_str: csv 行原字符串
+        :return: 解析后数值
+        """
+        # 解析函数调用
+        try:
+            return ParameterizeUtil.__parse_function(raw_str)
+        except Exception as e:
+            raise ValueError(f'invalid expression [{e.args[0]}]')
 
     @staticmethod
-    def __parse_func_all(expression: Text):
-        """
-        解析函数表达式
-        """
-        pattern = r'(\${)(mock|app)(__)(\w+?)(\(\))?(})'
+    def __parse_function(expression: Text):
+        """解析函数调用"""
+        pattern = r'\${(mock|app)__(\w+?)\((.*?)\)}'
         matched_list = re.findall(pattern, expression)
 
+        # 已匹配列表
         if not matched_list or len(matched_list) < 1:
             return expression
 
         # 替换解析后数值
-        matched_list = [ParameterizeUtil.__eval(items[1], items[3]) or ''.join(items) for items in matched_list]
+        _format = '${%s__%s(%s)}'
+        matched_list = [
+            ParameterizeUtil.__function_call(
+                items[0], items[1], items[2]
+            ) or _format % items for items in matched_list
+        ]
 
         expression = re.sub(pattern=pattern, repl="{}", string=expression)
         return expression.format(*matched_list)
 
     @staticmethod
-    def __eval(prefix: Text, function_name: Text):
-        """解析表达式"""
+    def __function_call(prefix: Text, function_name: Text, parameters: Text):
+        """函数调用"""
+        # 参数
+        if StrUtil.is_blank(parameters):
+            args = []
+        else:
+            args = [arg.strip() for arg in parameters.split(',')]
+
         try:
             if prefix == 'mock':
-                return eval(f'fa.{function_name}()')
+                return eval(f'fa.{function_name}({parameters})')
             elif prefix == 'app':
                 app_function = APPLICATION_FUNCTIONS.get(function_name)
-                return app_function() if app_function else None
+                return app_function(*args) if app_function else None
             else:
                 return None
         except AttributeError:
