@@ -6,15 +6,18 @@ from selenium import webdriver
 from melon.settings import get_config
 
 
+_DRIVER_ROUTER = dict(CHROME=webdriver.Chrome, FIREFOX=webdriver.Firefox, IE=webdriver.Ie, EDGE=webdriver.Edge)
+
+
 def create_driver():
-    driver_map = dict(CHROME=webdriver.Chrome, FIREFOX=webdriver.Firefox, IE=webdriver.Ie, EDGE=webdriver.Edge)
+    """构建单例 web driver"""
 
     url = get_config('melon.selenium.url')
-    assert url and url != '', 'URL不能为空'
+    assert url and url != '', 'URL must not be blank'
 
     browser_type = get_config('melon.selenium.browser', 'CHROME')
-    func = driver_map.get(browser_type.upper())
-    assert func, f'不支持的浏览器: [{browser_type}]'
+    func = _DRIVER_ROUTER.get(browser_type.upper())
+    assert func, f'not supported browser [{browser_type}]'
 
     _driver = func()
 
